@@ -459,5 +459,5 @@ class TestLoadData:
         connector.load_data(five_column_dataset(100), bad_object_id, m, _replace, batch_number=1, total_batches=1)
         connector.authenticate()
         objects = connector.get_objects()
-        assert bad_object_id in objects[]
+        assert bad_object_id in objects["object_id"]
 
